from . import generic

def find_boundary_cells(data_container_array, feature_ids_array_path = None, boundary_cells_array_name = None, ignore_feature_zero = None, include_volume_boundary = None, observer = None) -> int:
  """Pythonic interface to FindBoundaryCells Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    boundary_cells_array_name (QString): Sets the "BoundaryCellsArrayName" filter property
    ignore_feature_zero (bool): Sets the "IgnoreFeatureZero" filter property
    include_volume_boundary (bool): Sets the "IncludeVolumeBoundary" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.FindBoundaryCells()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if boundary_cells_array_name is not None:
    filter.BoundaryCellsArrayName = boundary_cells_array_name
  if ignore_feature_zero is not None:
    filter.IgnoreFeatureZero = ignore_feature_zero
  if include_volume_boundary is not None:
    filter.IncludeVolumeBoundary = include_volume_boundary
  filter.execute()
  return filter.ErrorCode

def find_bounding_box_features(data_container_array, calc_by_phase = None, centroids_array_path = None, phases_array_path = None, surface_features_array_path = None, biased_features_array_name = None, observer = None) -> int:
  """Pythonic interface to FindBoundingBoxFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    calc_by_phase (bool): Sets the "CalcByPhase" filter property
    centroids_array_path (DataArrayPath): Sets the "CentroidsArrayPath" filter property
    phases_array_path (DataArrayPath): Sets the "PhasesArrayPath" filter property
    surface_features_array_path (DataArrayPath): Sets the "SurfaceFeaturesArrayPath" filter property
    biased_features_array_name (QString): Sets the "BiasedFeaturesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.FindBoundingBoxFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if calc_by_phase is not None:
    filter.CalcByPhase = calc_by_phase
  if centroids_array_path is not None:
    filter.CentroidsArrayPath = centroids_array_path
  if phases_array_path is not None:
    filter.PhasesArrayPath = phases_array_path
  if surface_features_array_path is not None:
    filter.SurfaceFeaturesArrayPath = surface_features_array_path
  if biased_features_array_name is not None:
    filter.BiasedFeaturesArrayName = biased_features_array_name
  filter.execute()
  return filter.ErrorCode

def find_feature_centroids(data_container_array, feature_ids_array_path = None, centroids_array_path = None, observer = None) -> int:
  """Pythonic interface to FindFeatureCentroids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    centroids_array_path (DataArrayPath): Sets the "CentroidsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.FindFeatureCentroids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if centroids_array_path is not None:
    filter.CentroidsArrayPath = centroids_array_path
  filter.execute()
  return filter.ErrorCode

def find_feature_phases(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, feature_phases_array_path = None, observer = None) -> int:
  """Pythonic interface to FindFeaturePhases Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.FindFeaturePhases()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  filter.execute()
  return filter.ErrorCode

def find_feature_phases_binary(data_container_array, feature_ids_array_path = None, good_voxels_array_path = None, feature_phases_array_path = None, cell_ensemble_attribute_matrix_name = None, observer = None) -> int:
  """Pythonic interface to FindFeaturePhasesBinary Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.FindFeaturePhasesBinary()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def find_surface_features(data_container_array, feature_ids_array_path = None, surface_features_array_path = None, observer = None) -> int:
  """Pythonic interface to FindSurfaceFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    surface_features_array_path (DataArrayPath): Sets the "SurfaceFeaturesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.FindSurfaceFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if surface_features_array_path is not None:
    filter.SurfaceFeaturesArrayPath = surface_features_array_path
  filter.execute()
  return filter.ErrorCode

def generate_vector_colors(data_container_array, vectors_array_path = None, good_voxels_array_path = None, cell_vector_colors_array_name = None, use_good_voxels = None, observer = None) -> int:
  """Pythonic interface to GenerateVectorColors Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    vectors_array_path (DataArrayPath): Sets the "VectorsArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    cell_vector_colors_array_name (QString): Sets the "CellVectorColorsArrayName" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = generic.GenerateVectorColors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vectors_array_path is not None:
    filter.VectorsArrayPath = vectors_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if cell_vector_colors_array_name is not None:
    filter.CellVectorColorsArrayName = cell_vector_colors_array_name
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  filter.execute()
  return filter.ErrorCode

